#
# spec file for package gitlab-container-registry
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gitlab-container-registry
Version:        4.21.0
Release:        1.1
Summary:        The GitLab Container Registry
License:        Apache-2.0
Group:          System/Management
URL:            https://gitlab.com/gitlab-org/container-registry
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        %{name}-configuration.yml
Source3:        %{name}.service
Source4:       system-user-%{name}.conf
BuildRequires:  golang(API) >= 1.23
BuildRequires:  systemd-rpm-macros
BuildRequires:  sysuser-tools

%description
The GitLab Container Registry originated as a fork of the Docker Distribution
Registry, now CNCF Distribution, both distributed under Apache License Version
2.0.

The first GitLab change on top of the upstream implementation was efe421fd, and
since then we have diverged enough to the point where we decided to detach from
upstream and proceed on our own path.

Since then, we have implemented and released several major performance
improvements and bug fixes. For a list of changes, please see differences from
upstream
(https://gitlab.com/gitlab-org/container-registry/-/blob/master/docs/upstream-differences.md).
These changes culminated on a new architecture based on a relational
metadata database and the original goal, enabling online garbage collection
(https://gitlab.com/gitlab-org/container-registry/-/blob/master/docs/spec/gitlab/online-garbage-collection.md).

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %{_sourcedir}/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/docker/distribution/version.Version=%{version} \
   -X github.com/docker/distribution/version.Revision=${COMMIT_HASH} \
   -X github.com/docker/distribution/version.Package=github.com/docker/distribution \
   -X github.com/docker/distribution/version.BuildTime=${BUILD_DATE}" \
   -o bin/%{name} ./cmd/registry

%sysusers_generate_pre %{SOURCE4} %{name} system-user-%{name}.conf

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

#
# configuration directory in /etc/
#
install -D -m 644 %{SOURCE1} %{buildroot}/%{_sysconfdir}/%{name}/config.yml

#
# directory in /var/lib/
#
install -d  %{buildroot}%{_localstatedir}/lib/%{name}

#
# system user
#
install -d -m 755 %{buildroot}%{_sysusersdir}
install -D -m 0644 %{SOURCE4} %{buildroot}%{_sysusersdir}/

#
# systemd service
#
install -d -m 0755 %{buildroot}%{_sbindir}
install -D -m 0644 %{SOURCE3} %{buildroot}%{_unitdir}/%{name}.service

%check
%{buildroot}/%{_bindir}/%{name} --version

%pre -f %{name}.pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_unitdir}/%{name}.service
%{_sysusersdir}/system-user-%{name}.conf
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/config.yml
%dir %attr(-,%{name},%{name}) %{_localstatedir}/lib/%{name}

%changelog
* Tue Apr 29 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 4.21.0:
  * Features
  - datastore: add index on manifests id field (60371d6)
  - decouple npdm from pdm migrations (8e28d8f)
  - registry: require auth for v1 statistics API endpoint
    (5b4f3f9)
  - wrap query row context calls during DLB (719f05f)
  * Build
  - deps: update module github.com/aws/aws-sdk-go-v2/config to
    v1.29.14 (8d2c201)
  - deps: update module
    github.com/azure/azure-sdk-for-go/sdk/storage/azblob to
    v1.6.1 (da51247)
  - deps: update module
    github.com/testcontainers/testcontainers-go to v0.36.0
    (8d49261)
  - deps: update module gitlab.com/gitlab-org/api/client-go to
    v0.128.0 (cba984d)
* Fri Apr 18 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 4.20.0:
  * Features
  - allow for specifying more than one event type to log in s3
    drivers (0f88aaa)
  - optimize aws s3_v2 Write() code (29d3c47)
  - refresh replica list on network errors immediately (819aa46)
  - registry: add v1 statistics API endpoint (d155bc9)
  - rewrite s3_v2 driver from deprecated aws-sdk-go to
    aws-sdk-go-v2 (4d4d339)
  - switch aws cloudfront signer from aws-sdk-go to aws-sdk-go-v2
    (2d7245b)
  * Bug Fixes
  - adjust maximum value of chunksize option for s3 storage
    drivers (b3a9288)
  - avoid appending directory as file path in s3 driver Walk
    (2aad72e)
  - fix potential resource leak by ensuring the response body is
    closed in HTTPReadSeeker (d476f92)
  - honour aws part size limit when re-uploading objects in aws
    s3_v2 driver (5ea107d)
  - improve storage driver logging, redirect driver logs to the
    main logger (5efa19d)
  - new installations via omnibus lock the file system (d02e775)
  - prevent panics due to nil pointer dereference in s3 v2
    (68f6712)
  - proper error handling in s3_v2 Delete() call (2812633)
  - set proper boundary when re-uploading parts (7c22aa1)
  - stop report to sentry on redis ctx deadline in
    checkOngoingRename (6d472a5)
  - take manifest subject ID references into account during
    online GC (b0355e7)
  - use the right context for goroutine cancelation (b2e6be2)
  * Build
  - deps: update dependency danger-review to v2.1.0 (8c1a69a)
  - deps: update module cloud.google.com/go/storage to v1.51.0
    (9caabc9)
  - deps: update module cloud.google.com/go/storage to v1.51.0,
    adjust code to make CI pass (6ea9bb5)
  - deps: update module github.com/aws/aws-sdk-go-v2/service/s3
    to v1.79.1 (376c6e0)
  - deps: update module github.com/aws/aws-sdk-go-v2/service/s3
    to v1.79.2 (6153705)
  - deps: update module
    github.com/azure/azure-sdk-for-go/sdk/azcore to v1.17.1
    (02e2e54)
  - deps: update module
    github.com/azure/azure-sdk-for-go/sdk/azcore to v1.18.0
    (1891708)
  - deps: update module
    github.com/azure/azure-sdk-for-go/sdk/azidentity to v1.9.0
    (e7e3c7e)
  - deps: update module github.com/getsentry/sentry-go to v0.32.0
    (41dba64)
  - deps: update module github.com/jackc/pgx/v5 to v5.7.4
    (535eedf)
  - deps: update module github.com/prometheus/client_golang to
    v1.22.0 (87f4cb4)
  - deps: update module github.com/spf13/viper to v1.20.1
    (46e48b0)
  - deps: update module gitlab.com/gitlab-org/api/client-go to
    v0.126.0 (60dcd75)
  - deps: update module gitlab.com/gitlab-org/api/client-go to
    v0.127.0 (211c92a)
  - deps: update module gitlab.com/gitlab-org/labkit to v1.23.2
    (7853ab6)
  - deps: update module go.uber.org/mock to v0.5.1 (e0a9cbc)
  - deps: update module golang.org/x/crypto to v0.37.0 (e6dbcd4)
  - deps: update module golang.org/x/net to v0.38.0 (21ab302)
  - deps: update module golang.org/x/net to v0.39.0 (ed38664)
  - deps: update module golang.org/x/oauth2 to v0.29.0 (84dbf5d)
  - deps: update module google.golang.org/api to v0.228.0
    (7e6433d)
  - deps: update module google.golang.org/api to v0.229.0
    (e40ae14)
* Mon Mar 24 2025 opensuse_buildservice@ojkastl.de
- Update to version 4.19.0:
  * Features
  - datastore: add index on manifests subject_id field (e1a5821)
  * Build
  - deps: update module github.com/redis/go-redis/v9 to v9.7.3
    (58d51a8)
  - deps: update module github.com/shopify/toxiproxy/v2 to
    v2.12.0 (9d5716e)
  - deps: update module github.com/spf13/viper to v1.20.0
    (840a550)
  - deps: update module google.golang.org/api to v0.226.0
    (9be95f3)
  - update Go version to latest 1.23 minor release (2cde241)
* Mon Mar 17 2025 opensuse_buildservice@ojkastl.de
- Update to version 4.18.0:
  * Features
  - api: log tag delete events (045dc26)
  - datastore: support dedicated redis connection for DB load
    balancing (98fa3f0)
  * Bug Fixes
  - cancel existing multipart uploads when starting new one for
    the same path for s3_v2 driver (44a0d98)
  * Build
  - deps: update module github.com/prometheus/client_golang to
    v1.21.1 (801010a)
  - deps: update module golang.org/x/crypto to v0.36.0 (eb38c8c)
  - deps: update module golang.org/x/oauth2 to v0.28.0 (33c43e9)
* Fri Mar  7 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package gitlab-container-registry: Gitlab's fork of the Docker
  Distribution Registry (now called CNCF Distribution)
